;;; dot.wl-highlight-subdued.el --- subdued highlighting for Wanderlust  -*-mode: emacs-lisp-*-

;; Copyright (C) 2021 Tatsuya Kinoshita

;; Released under the terms of the CC0 Public Domain Dedication.
;; <https://creativecommons.org/publicdomain/zero/1.0/>

;; Usage: copy to ~/.wl-highlight.el, and put (load "~/.wl-highlight") in ~/.wl

;;; Code:

(when t
  (set-face-foreground 'wl-highlight-message-headers nil)
  (set-face-bold       'wl-highlight-message-headers nil)
  (set-face-foreground 'wl-highlight-message-header-contents nil)
  (set-face-bold       'wl-highlight-message-header-contents nil)
  (set-face-foreground 'wl-highlight-message-important-header-contents nil)
  (set-face-bold       'wl-highlight-message-important-header-contents nil)
  (set-face-foreground 'wl-highlight-message-important-header-contents2 nil)
  (set-face-bold       'wl-highlight-message-important-header-contents2 nil)
  (set-face-foreground 'wl-highlight-message-citation-header nil)
  (set-face-bold       'wl-highlight-message-citation-header nil)
  (set-face-foreground 'wl-highlight-message-unimportant-header-contents nil)
  (set-face-bold       'wl-highlight-message-unimportant-header-contents nil)
  (set-face-foreground 'wl-highlight-message-signature nil)
  (set-face-bold       'wl-highlight-message-signature nil)
  ;;(set-face-foreground 'wl-highlight-header-separator-face nil)
  ;;(set-face-background 'wl-highlight-header-separator-face nil)
  ;;(set-face-bold       'wl-highlight-header-separator-face nil)
  (set-face-foreground 'wl-highlight-summary-flagged-face nil)
  (set-face-bold       'wl-highlight-summary-flagged-face nil)
  (set-face-foreground 'wl-highlight-summary-new-face nil)
  (set-face-bold       'wl-highlight-summary-new-face nil)
  (set-face-foreground 'wl-highlight-summary-killed-face nil)
  (set-face-bold       'wl-highlight-summary-killed-face nil)
  (set-face-foreground 'wl-highlight-summary-displaying-face nil)
  (set-face-bold       'wl-highlight-summary-displaying-face nil)
  (set-face-foreground 'wl-highlight-thread-indent-face nil)
  (set-face-bold       'wl-highlight-thread-indent-face nil)
  (set-face-foreground 'wl-highlight-summary-unread-face nil)
  (set-face-bold       'wl-highlight-summary-unread-face nil)
  (set-face-foreground 'wl-highlight-summary-disposed-face nil)
  (set-face-bold       'wl-highlight-summary-disposed-face nil)
  (set-face-foreground 'wl-highlight-summary-deleted-face nil)
  (set-face-bold       'wl-highlight-summary-deleted-face nil)
  (set-face-foreground 'wl-highlight-summary-prefetch-face nil)
  (set-face-bold       'wl-highlight-summary-prefetch-face nil)
  (set-face-foreground 'wl-highlight-summary-resend-face nil)
  (set-face-bold       'wl-highlight-summary-resend-face nil)
  (set-face-foreground 'wl-highlight-summary-refiled-face nil)
  (set-face-bold       'wl-highlight-summary-refiled-face nil)
  (set-face-foreground 'wl-highlight-summary-copied-face nil)
  (set-face-bold       'wl-highlight-summary-copied-face nil)
  (set-face-foreground 'wl-highlight-summary-answered-face nil)
  (set-face-bold       'wl-highlight-summary-answered-face nil)
  (set-face-foreground 'wl-highlight-summary-forwarded-face nil)
  (set-face-bold       'wl-highlight-summary-forwarded-face nil)
  (set-face-foreground 'wl-summary-persistent-mark-face nil)
  (set-face-bold       'wl-summary-persistent-mark-face nil)
  (set-face-foreground 'wl-highlight-summary-temp-face nil)
  (set-face-bold       'wl-highlight-summary-temp-face nil)
  (set-face-foreground 'wl-highlight-summary-target-face nil)
  (set-face-bold       'wl-highlight-summary-target-face nil)
  (set-face-foreground 'wl-highlight-summary-low-read-face nil)
  (set-face-bold       'wl-highlight-summary-low-read-face nil)
  (set-face-foreground 'wl-highlight-summary-high-read-face nil)
  (set-face-bold       'wl-highlight-summary-high-read-face nil)
  (set-face-foreground 'wl-highlight-summary-low-unread-face nil)
  (set-face-bold       'wl-highlight-summary-low-unread-face nil)
  (set-face-foreground 'wl-highlight-summary-high-unread-face nil)
  (set-face-bold       'wl-highlight-summary-high-unread-face nil)
  (set-face-foreground 'wl-highlight-summary-thread-top-face nil)
  (set-face-bold       'wl-highlight-summary-thread-top-face nil)
  (set-face-foreground 'wl-highlight-summary-normal-face nil)
  (set-face-bold       'wl-highlight-summary-normal-face nil)
  (set-face-foreground 'wl-highlight-folder-unknown-face nil)
  (set-face-bold       'wl-highlight-folder-unknown-face nil)
  (set-face-foreground 'wl-highlight-folder-killed-face nil)
  (set-face-bold       'wl-highlight-folder-killed-face nil)
  (set-face-foreground 'wl-highlight-folder-zero-face nil)
  (set-face-bold       'wl-highlight-folder-zero-face nil)
  (set-face-foreground 'wl-highlight-folder-few-face nil)
  (set-face-bold       'wl-highlight-folder-few-face nil)
  (set-face-foreground 'wl-highlight-folder-many-face nil)
  (set-face-bold       'wl-highlight-folder-many-face nil)
  (set-face-foreground 'wl-highlight-folder-unread-face nil)
  (set-face-bold       'wl-highlight-folder-unread-face nil)
  (set-face-foreground 'wl-highlight-folder-opened-face nil)
  (set-face-bold       'wl-highlight-folder-opened-face nil)
  (set-face-foreground 'wl-highlight-folder-closed-face nil)
  (set-face-bold       'wl-highlight-folder-closed-face nil)
  (set-face-foreground 'wl-highlight-folder-path-face nil)
  (set-face-bold       'wl-highlight-folder-path-face nil)
  ;;(set-face-foreground 'wl-highlight-demo-face nil)
  ;;(set-face-background 'wl-highlight-demo-face nil)
  ;;(set-face-bold       'wl-highlight-demo-face nil)
  ;;(set-face-foreground 'wl-highlight-logo-face nil)
  ;;(set-face-background 'wl-highlight-logo-face nil)
  ;;(set-face-bold       'wl-highlight-logo-face nil)
  (set-face-foreground 'wl-highlight-action-argument-face nil)
  (set-face-bold       'wl-highlight-action-argument-face nil)
  (set-face-foreground 'wl-highlight-message-cited-text-1 nil)
  (set-face-bold       'wl-highlight-message-cited-text-1 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-2 nil)
  (set-face-bold       'wl-highlight-message-cited-text-2 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-3 nil)
  (set-face-bold       'wl-highlight-message-cited-text-3 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-4 nil)
  (set-face-bold       'wl-highlight-message-cited-text-4 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-5 nil)
  (set-face-bold       'wl-highlight-message-cited-text-5 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-6 nil)
  (set-face-bold       'wl-highlight-message-cited-text-6 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-7 nil)
  (set-face-bold       'wl-highlight-message-cited-text-7 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-8 nil)
  (set-face-bold       'wl-highlight-message-cited-text-8 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-9 nil)
  (set-face-bold       'wl-highlight-message-cited-text-9 nil)
  (set-face-foreground 'wl-highlight-message-cited-text-10 nil)
  (set-face-bold       'wl-highlight-message-cited-text-10 nil)
  ;;(set-face-foreground 'wl-message-header-narrowing-face nil)
  ;;(set-face-background 'wl-message-header-narrowing-face nil)
  ;;(set-face-bold       'wl-message-header-narrowing-face nil)
  )

(cond
 ((< (display-color-cells) 256)
  (set-face-bold       'wl-highlight-message-important-header-contents t)
  (set-face-bold       'wl-highlight-message-important-header-contents2 t)
  (set-face-bold       'wl-highlight-summary-new-face t)
  (set-face-bold       'wl-highlight-summary-unread-face t)
  (set-face-bold       'wl-highlight-summary-low-unread-face t)
  (set-face-bold       'wl-highlight-summary-high-unread-face t)
  (set-face-bold       'wl-highlight-folder-few-face t)
  (set-face-bold       'wl-highlight-folder-many-face t)
  (set-face-bold       'wl-highlight-folder-unread-face t)
  ;;
  )
 ((eq (frame-parameter nil 'background-mode) 'dark)
  (set-face-foreground 'wl-highlight-message-headers "gray70")
  (set-face-foreground 'wl-highlight-message-header-contents "gray70")
  (set-face-foreground 'wl-highlight-message-important-header-contents "gray89")
  (set-face-bold       'wl-highlight-message-important-header-contents t)
  (set-face-foreground 'wl-highlight-message-important-header-contents2 "gray89")
  (set-face-bold       'wl-highlight-message-important-header-contents2 t)
  (set-face-foreground 'wl-highlight-message-unimportant-header-contents "gray70")
  (set-face-foreground 'wl-highlight-summary-new-face "gray89")
  (set-face-bold       'wl-highlight-summary-new-face t)
  (set-face-foreground 'wl-highlight-summary-unread-face "gray78")
  (set-face-bold       'wl-highlight-summary-unread-face t)
  (set-face-foreground 'wl-highlight-summary-low-unread-face "gray70")
  (set-face-bold       'wl-highlight-summary-low-unread-face t)
  (set-face-foreground 'wl-highlight-summary-high-unread-face "gray89")
  (set-face-bold       'wl-highlight-summary-high-unread-face t)
  (set-face-foreground 'wl-highlight-folder-few-face "gray89")
  (set-face-bold       'wl-highlight-folder-few-face t)
  (set-face-foreground 'wl-highlight-folder-many-face "gray70")
  (set-face-bold       'wl-highlight-folder-many-face t)
  (set-face-foreground 'wl-highlight-folder-unread-face "gray78")
  (set-face-bold       'wl-highlight-folder-unread-face t)
  (set-face-foreground 'wl-highlight-message-cited-text-1  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-2  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-3  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-4  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-5  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-6  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-7  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-8  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-9  "DarkSeaGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-10 "DarkSeaGreen")
  ;;
  )
 (t
  (set-face-foreground 'wl-highlight-message-headers "gray58")
  (set-face-foreground 'wl-highlight-message-header-contents "gray58")
  (set-face-foreground 'wl-highlight-message-important-header-contents "gray23")
  (set-face-bold       'wl-highlight-message-important-header-contents t)
  (set-face-foreground 'wl-highlight-message-important-header-contents2 "gray23")
  (set-face-bold       'wl-highlight-message-important-header-contents2 t)
  (set-face-foreground 'wl-highlight-message-unimportant-header-contents "gray58")
  (set-face-foreground 'wl-highlight-summary-new-face "gray23")
  (set-face-bold       'wl-highlight-summary-new-face t)
  (set-face-foreground 'wl-highlight-summary-unread-face "gray39")
  (set-face-bold       'wl-highlight-summary-unread-face t)
  (set-face-foreground 'wl-highlight-summary-low-unread-face "gray58")
  (set-face-bold       'wl-highlight-summary-low-unread-face t)
  (set-face-foreground 'wl-highlight-summary-high-unread-face "gray23")
  (set-face-bold       'wl-highlight-summary-high-unread-face t)
  (set-face-foreground 'wl-highlight-folder-few-face "gray23")
  (set-face-bold       'wl-highlight-folder-few-face t)
  (set-face-foreground 'wl-highlight-folder-many-face "gray58")
  (set-face-bold       'wl-highlight-folder-many-face t)
  (set-face-foreground 'wl-highlight-folder-unread-face "gray39")
  (set-face-bold       'wl-highlight-folder-unread-face t)
  (set-face-foreground 'wl-highlight-message-cited-text-1  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-2  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-3  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-4  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-5  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-6  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-7  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-8  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-9  "DarkGreen")
  (set-face-foreground 'wl-highlight-message-cited-text-10 "DarkGreen")
  ;;
  ))

;;; dot.wl-highlight-subdued.el ends here
